<?php
/*
Plugin Name: Coupons Weekday Limiter (EasyToolsWP)
Description: Adds a dropdown to coupons to limit them to specific weekdays.
Version: 1.0.2
Author: EasyToolsWP.com
Requires Plugins:  woocommerce
*/

defined( 'ABSPATH' ) || exit;

// Add custom fields to coupon form
add_action( 'woocommerce_coupon_options', 'add_weekday_limit_field' );
function add_weekday_limit_field() {
    global $post;

    echo '<div class="options_group">';
    woocommerce_wp_select( array(
        'id'            => 'weekday_limit',
        'label'         => __( 'Weekday Limit', 'woocommerce' ),
        'description'   => __( 'Choose weekday to limit this coupon.', 'woocommerce' ),
        'options'       => array(
            ''            => __( 'No Restriction', 'woocommerce' ),
            'monday'      => __( 'Monday', 'woocommerce' ),
            'tuesday'     => __( 'Tuesday', 'woocommerce' ),
            'wednesday'   => __( 'Wednesday', 'woocommerce' ),
            'thursday'    => __( 'Thursday', 'woocommerce' ),
            'friday'      => __( 'Friday', 'woocommerce' ),
            'saturday'    => __( 'Saturday', 'woocommerce' ),
            'sunday'      => __( 'Sunday', 'woocommerce' ),
        ),
    ) );
    echo '</div>';
}

// Save custom fields
add_action( 'woocommerce_coupon_options_save', 'save_weekday_limit_field' );
function save_weekday_limit_field( $post_id ) {
    $weekday_limit = isset( $_POST['weekday_limit'] ) ? sanitize_text_field( $_POST['weekday_limit'] ) : '';
    update_post_meta( $post_id, 'weekday_limit', $weekday_limit );
}

// Check if coupon is valid for current weekday
add_filter( 'woocommerce_coupon_is_valid', 'check_weekday_coupon_validity', 10, 2 );
function check_weekday_coupon_validity( $is_valid, $coupon ) {
    $weekday_limit = get_post_meta( $coupon->get_id(), 'weekday_limit', true );

    if ( ! empty( $weekday_limit ) ) {
        $current_weekday = strtolower( date( 'l' ) ); // Get current weekday in lowercase

        // Check if current weekday matches the coupon's weekday limit
        if ( $current_weekday !== $weekday_limit ) {
            $is_valid = false;
        }
    }

    return $is_valid;
}

// Function to create coupons for all weekdays on plugin activation
register_activation_hook( __FILE__, 'create_weekday_coupons' );
function create_weekday_coupons() {
    $coupons = array(
        'monday_today' => array(
            'weekday_limit'     => 'monday',
            'amount'            => 3,
        ),
        'tuesday_today' => array(
            'weekday_limit'     => 'tuesday',
            'amount'            => 5,
        ),
        'wednesday_today' => array(
            'weekday_limit'     => 'wednesday',
            'amount'            => 7,
        ),
        'thursday_today' => array(
            'weekday_limit'     => 'thursday',
            'amount'            => 10,
        ),
        'friday_today' => array(
            'weekday_limit'     => 'friday',
            'amount'            => 10,
        ),
        'saturday_today' => array(
            'weekday_limit'     => 'saturday',
            'amount'            => 15,
        ),
        'sunday_today' => array(
            'weekday_limit'     => 'sunday',
            'amount'            => 15,
        ),
    );

    foreach ( $coupons as $coupon_code => $coupon_args ) {
        $coupon = new WC_Coupon();
        $coupon->set_code( $coupon_code );
        $coupon->set_discount_type( 'percent' ); // Rabattype som procent
        $coupon->set_amount( $coupon_args['amount'] ); // Procentrabat beløb
        $coupon->set_individual_use( true );
        $coupon->set_usage_limit( 1 );

        // Set weekday limit metadata
        update_post_meta( $coupon->get_id(), 'weekday_limit', $coupon_args['weekday_limit'] );

        $coupon->save();
    }
}
